@@ -6,7 +6,7 @@ x <- matrix(x, 1, d)
 # Compute y.min if missing
 if (is.null(y.min))
 {
-  pred <- predict.km(model, newdata=model@X, type="UK")
+  pred <- predict(model, newdata=model@X, type="UK", checkNames = FALSE)
   mk <- pred$mean
   sk <- pred$sd
   qk <- mk + qnorm(0.75)*sk
