@@ -1,10 +1,8 @@
 EI.grad <- function(x, model, envir) {
-	
-   get("kriging.sd", envir=envir)
 
-	if (kriging.sd < 1e-06) {
+	if (envir$kriging.sd < 1e-06) {
 		d <- length(x)
-	   	rep(0,d)
+	   	return(rep(0,d))
    	} else {
 		toget <- matrix(c("xcr", "xcr.prob", "xcr.dens", "c", "Tinv.c"),1,5)
     	apply(toget, 2, get, envir=envir)
